@@ -312,14 +312,14 @@ end
 -- @return table or nil: A table containing fields 'name' and 'version'
 -- representing an installed rock which matches the given dependency,
 -- or nil if it could not be matched.
-local function match_dep(dep, blacklist)
+local function match_dep(dep, blacklist, deps_mode)
    assert(type(dep) == "table")
 
    local versions
    if dep.name == "lua" then
       versions = { cfg.lua_version }
    else
-      versions = manif_core.get_versions(dep.name)
+      versions = manif_core.get_versions(dep.name, deps_mode)
    end
    if not versions then
       return nil
@@ -361,13 +361,13 @@ end
 -- in table format and values are tables containing fields 'name' and
 -- version' representing matches, and a table of missing dependencies
 -- parsed as tables.
-function match_deps(rockspec, blacklist)
+function match_deps(rockspec, blacklist, deps_mode)
    assert(type(rockspec) == "table")
    assert(type(blacklist) == "table" or not blacklist)
    local matched, missing, no_upgrade = {}, {}, {}
 
    for _, dep in ipairs(rockspec.dependencies) do
-      local found = match_dep(dep, blacklist and blacklist[dep.name] or nil)
+      local found = match_dep(dep, blacklist and blacklist[dep.name] or nil, deps_mode)
       if found then
          if dep.name ~= "lua" then 
             matched[dep] = found
@@ -401,7 +401,7 @@ end
 -- @return boolean or (nil, string, [string]): True if no errors occurred, or
 -- nil and an error message if any test failed, followed by an optional
 -- error code.
-function fulfill_dependencies(rockspec)
+function fulfill_dependencies(rockspec, deps_mode)
 
    local search = require("luarocks.search")
    local install = require("luarocks.install")
@@ -433,7 +433,7 @@ function fulfill_dependencies(rockspec)
       end
    end
 
-   local matched, missing, no_upgrade = match_deps(rockspec)
+   local matched, missing, no_upgrade = match_deps(rockspec, nil, deps_mode)
 
    if next(no_upgrade) then
       util.printerr("Missing dependencies for "..rockspec.name.." "..rockspec.version..":")
@@ -467,7 +467,7 @@ function fulfill_dependencies(rockspec)
 
       for _, dep in pairs(missing) do
          -- Double-check in case dependency was filled during recursion.
-         if not match_dep(dep) then
+         if not match_dep(dep, nil, deps_mode) then
             local rock = search.find_suitable_rock(dep)
             if not rock then
                return nil, "Could not satisfy dependency: "..show_dep(dep)
@@ -482,6 +482,31 @@ function fulfill_dependencies(rockspec)
    return true
 end
 
+--- If filename matches a pattern, return the capture.
+-- For example, given "libfoo.so" and "lib?.so" is a pattern,
+-- returns "foo" (which can then be used to build names
+-- based on other patterns.
+-- @param file string: a filename
+-- @param pattern string: a pattern, where ? is to be matched by the filename.
+-- @return string The pattern, if found, or nil.
+local function deconstruct_pattern(file, pattern)
+   local depattern = "^"..(pattern:gsub("%.", "%%."):gsub("%*", ".*"):gsub("?", "(.*)")).."$"
+   return (file:match(depattern))
+end
+
+--- Construct all possible patterns for a name and add to the files array.
+-- Run through the patterns array replacing all occurrences of "?"
+-- with the given file name and store them in the files array.
+-- @param file string A raw name (e.g. "foo")
+-- @param array of string An array of patterns with "?" as the wildcard
+-- (e.g. {"?.so", "lib?.so"})
+-- @param files The array of constructed names
+local function add_all_patterns(file, patterns, files)
+   for _, pattern in ipairs(patterns) do
+      table.insert(files, (pattern:gsub("?", file)))
+   end
+end
+
 --- Set up path-related variables for external dependencies.
 -- For each key in the external_dependencies table in the
 -- rockspec file, four variables are created: <key>_DIR, <key>_BINDIR,
@@ -546,10 +571,14 @@ function check_external_deps(rockspec, mode)
                if file then
                   local files = {}
                   if not file:match("%.") then
-                     for _, pattern in ipairs(dirdata.pattern) do
-                        table.insert(files, (pattern:gsub("?", file)))
-                     end
+                     add_all_patterns(file, dirdata.pattern, files)
                   else
+                     for _, pattern in ipairs(dirdata.pattern) do
+                        local matched = deconstruct_pattern(file, pattern)
+                        if matched then
+                           add_all_patterns(matched, dirdata.pattern, files)
+                        end
+                     end
                      table.insert(files, file)
                   end
                   local found = false
@@ -611,7 +640,7 @@ end
 -- @param name string: Package name.
 -- @param version string: Package version.
 -- @return (table, table): The results and a table of missing dependencies.
-function scan_deps(results, missing, manifest, name, version)
+function scan_deps(results, missing, manifest, name, version, deps_mode)
    assert(type(results) == "table")
    assert(type(missing) == "table")
    assert(type(manifest) == "table")
@@ -640,9 +669,9 @@ function scan_deps(results, missing, manifest, name, version)
    else
       rockspec = { dependencies = deplist }
    end
-   local matched, failures = match_deps(rockspec)
+   local matched, failures = match_deps(rockspec, nil, deps_mode)
    for _, match in pairs(matched) do
-      results, missing = scan_deps(results, missing, manifest, match.name, match.version)
+      results, missing = scan_deps(results, missing, manifest, match.name, match.version, deps_mode)
    end
    if next(failures) then
       for _, failure in pairs(failures) do
@@ -652,3 +681,26 @@ function scan_deps(results, missing, manifest, name, version)
    results[name] = version
    return results, missing
 end
+
+local valid_deps_modes = {
+   one = true,
+   order = true,
+   all = true,
+   none = true,
+}
+
+function check_deps_mode_flag(flag)
+   return valid_deps_modes[flag]
+end
+
+function get_deps_mode(flags)
+   if flags["deps-mode"] then
+      return flags["deps-mode"]
+   else
+      return cfg.deps_mode
+   end
+end
+
+function deps_mode_to_flag(deps_mode)
+   return "--deps-mode="..deps_mode
+end
